# Kalman filter estimation

```bash
Email: autuanliu@163.com
```
[![Build Status](https://dev.azure.com/AutuanLiu/Kalman%20Filter/_apis/build/status/AutuanLiu.Kalman-Filter?branchName=master&jobName=Test&configuration=Python36)](https://dev.azure.com/AutuanLiu/Kalman%20Filter/_build/latest?definitionId=1?branchName=master)

![](https://img.shields.io/pypi/dm/kalman-estimation.svg)
![](https://img.shields.io/github/repo-size/badges/shields.svg)
![](https://img.shields.io/github/license/AutuanLiu/Kalman-Filter.svg)
![](https://img.shields.io/github/release/AutuanLiu/Kalman-Filter.svg)
![](https://img.shields.io/pypi/v/kalman-estimation.svg)
![](https://img.shields.io/pypi/pyversions/kalman-estimation.svg)

[Chinese Docs](https://www.yuque.com/xk6dxn/drboi7)

[Wiki](https://github.com/AutuanLiu/Kalman-Filter/wiki)

[README](https://dev.azure.com/AutuanLiu/Kalman%20Filter/_wiki/wikis/Kalman-Filter.wiki?wikiVersion=GBwikiMaster&pagePath=%2FKalman%20filter%20estimation)
